==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/dir_e2246a470efa11fe5ee09b98569d4f67.js <==
var dir_e2246a470efa11fe5ee09b98569d4f67 =
[
    [ "bisect.hpp", "opencl_2kernels_2bisect_8hpp.html", "opencl_2kernels_2bisect_8hpp" ],
    [ "compressed_compressed_matrix.hpp", "linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html", "linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp" ],
    [ "compressed_matrix.hpp", "linalg_2opencl_2kernels_2compressed__matrix_8hpp.html", "linalg_2opencl_2kernels_2compressed__matrix_8hpp" ],
    [ "coordinate_matrix.hpp", "linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html", "linalg_2opencl_2kernels_2coordinate__matrix_8hpp" ],
    [ "ell_matrix.hpp", "linalg_2opencl_2kernels_2ell__matrix_8hpp.html", "linalg_2opencl_2kernels_2ell__matrix_8hpp" ],
    [ "fft.hpp", "linalg_2opencl_2kernels_2fft_8hpp.html", "linalg_2opencl_2kernels_2fft_8hpp" ],
    [ "hyb_matrix.hpp", "linalg_2opencl_2kernels_2hyb__matrix_8hpp.html", "linalg_2opencl_2kernels_2hyb__matrix_8hpp" ],
    [ "ilu.hpp", "opencl_2kernels_2ilu_8hpp.html", "opencl_2kernels_2ilu_8hpp" ],
    [ "iterative.hpp", "iterative_8hpp.html", "iterative_8hpp" ],
    [ "matrix.hpp", "linalg_2opencl_2kernels_2matrix_8hpp.html", "linalg_2opencl_2kernels_2matrix_8hpp" ],
    [ "matrix_solve.hpp", "matrix__solve_8hpp.html", "matrix__solve_8hpp" ],
    [ "nmf.hpp", "opencl_2kernels_2nmf_8hpp.html", "opencl_2kernels_2nmf_8hpp" ],
    [ "scalar.hpp", "linalg_2opencl_2kernels_2scalar_8hpp.html", "linalg_2opencl_2kernels_2scalar_8hpp" ],
    [ "sliced_ell_matrix.hpp", "linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp.html", "linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp" ],
    [ "spai.hpp", "opencl_2kernels_2spai_8hpp.html", "opencl_2kernels_2spai_8hpp" ],
    [ "svd.hpp", "opencl_2kernels_2svd_8hpp.html", "opencl_2kernels_2svd_8hpp" ],
    [ "vector.hpp", "linalg_2opencl_2kernels_2vector_8hpp.html", "linalg_2opencl_2kernels_2vector_8hpp" ]
];

==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/dir_e2246a470efa11fe5ee09b98569d4f67.js <==
var dir_e2246a470efa11fe5ee09b98569d4f67 =
[
    [ "amg.hpp", "opencl_2kernels_2amg_8hpp.html", "opencl_2kernels_2amg_8hpp" ],
    [ "bisect.hpp", "opencl_2kernels_2bisect_8hpp.html", "opencl_2kernels_2bisect_8hpp" ],
    [ "compressed_compressed_matrix.hpp", "linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html", "linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp" ],
    [ "compressed_matrix.hpp", "linalg_2opencl_2kernels_2compressed__matrix_8hpp.html", "linalg_2opencl_2kernels_2compressed__matrix_8hpp" ],
    [ "coordinate_matrix.hpp", "linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html", "linalg_2opencl_2kernels_2coordinate__matrix_8hpp" ],
    [ "ell_matrix.hpp", "linalg_2opencl_2kernels_2ell__matrix_8hpp.html", "linalg_2opencl_2kernels_2ell__matrix_8hpp" ],
    [ "fft.hpp", "linalg_2opencl_2kernels_2fft_8hpp.html", "linalg_2opencl_2kernels_2fft_8hpp" ],
    [ "hyb_matrix.hpp", "linalg_2opencl_2kernels_2hyb__matrix_8hpp.html", "linalg_2opencl_2kernels_2hyb__matrix_8hpp" ],
    [ "ilu.hpp", "opencl_2kernels_2ilu_8hpp.html", "opencl_2kernels_2ilu_8hpp" ],
    [ "iterative.hpp", "iterative_8hpp.html", "iterative_8hpp" ],
    [ "matrix.hpp", "linalg_2opencl_2kernels_2matrix_8hpp.html", "linalg_2opencl_2kernels_2matrix_8hpp" ],
    [ "matrix_solve.hpp", "matrix__solve_8hpp.html", "matrix__solve_8hpp" ],
    [ "nmf.hpp", "opencl_2kernels_2nmf_8hpp.html", "opencl_2kernels_2nmf_8hpp" ],
    [ "scalar.hpp", "linalg_2opencl_2kernels_2scalar_8hpp.html", "linalg_2opencl_2kernels_2scalar_8hpp" ],
    [ "scan.hpp", "scan_8hpp.html", "scan_8hpp" ],
    [ "sliced_ell_matrix.hpp", "linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp.html", "linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp" ],
    [ "spai.hpp", "opencl_2kernels_2spai_8hpp.html", "opencl_2kernels_2spai_8hpp" ],
    [ "svd.hpp", "opencl_2kernels_2svd_8hpp.html", "opencl_2kernels_2svd_8hpp" ],
    [ "vector.hpp", "linalg_2opencl_2kernels_2vector_8hpp.html", "linalg_2opencl_2kernels_2vector_8hpp" ]
];
